package com.jeesite.modules.admin.apply.entity;

import javax.validation.constraints.Size;

import com.jeesite.common.entity.DataEntity;
import com.jeesite.common.mybatis.annotation.Column;
import com.jeesite.common.mybatis.annotation.Table;
import com.jeesite.common.mybatis.mapper.query.QueryType;

/**
 * 应用评价表Entity
 * @author yinet
 * @version 2022-06-16
 */
@Table(name="admin_app_evaluate", alias="a", label="应用评价表信息", columns={
		@Column(name="id", attrName="id", label="主键id", isPK=true),
		@Column(name="evaluate_user", attrName="evaluateUser", label="评价人员id"),
		@Column(name="evaluate_username", attrName="evaluateUsername", label="评价人姓名"),
		@Column(name="evaluate_app", attrName="evaluateApp", label="评价appid"),
		@Column(name="app_name", attrName="appName", label="应用名字", queryType=QueryType.LIKE),
		@Column(name="evaluate_msg", attrName="evaluateMsg", label="评价信息"),
		@Column(name="evaluate_image", attrName="evaluateImage", label="评价图片"),
		@Column(name="app_describe", attrName="appDescribe", label="应用描述"),
		@Column(name="score", attrName="score", label="分数"),
		@Column(name="create_by", attrName="createBy", label="创建者", isUpdate=false, isQuery=false),
		@Column(name="create_date", attrName="createDate", label="创建时间", isUpdate=false, isQuery=false, isUpdateForce=true),
		@Column(name="update_by", attrName="updateBy", label="更新者", isQuery=false),
		@Column(name="update_date", attrName="updateDate", label="更新时间", isQuery=false, isUpdateForce=true),
		@Column(name="remarks", attrName="remarks", label="备注信息", queryType=QueryType.LIKE),
	}, orderBy="a.update_date DESC"
)
public class AdminAppEvaluate extends DataEntity<AdminAppEvaluate> {
	
	private static final long serialVersionUID = 1L;
	private String evaluateUser;		// 评价人员id
	private String evaluateUsername;		// 评价人姓名
	private String evaluateApp;		// 评价appid
	private String appName;		// 应用名字
	private String evaluateMsg;		// 评价信息
	private String evaluateImage;		// 评价图片
	private String appDescribe;		// 应用描述
	private String score;		// 分数
	
	public AdminAppEvaluate() {
		this(null);
	}
	
	public AdminAppEvaluate(String id){
		super(id);
	}
	
	@Size(min=0, max=255, message="评价人员id长度不能超过 255 个字符")
	public String getEvaluateUser() {
		return evaluateUser;
	}

	public void setEvaluateUser(String evaluateUser) {
		this.evaluateUser = evaluateUser;
	}
	
	@Size(min=0, max=255, message="评价人姓名长度不能超过 255 个字符")
	public String getEvaluateUsername() {
		return evaluateUsername;
	}

	public void setEvaluateUsername(String evaluateUsername) {
		this.evaluateUsername = evaluateUsername;
	}
	
	@Size(min=0, max=255, message="评价appid长度不能超过 255 个字符")
	public String getEvaluateApp() {
		return evaluateApp;
	}

	public void setEvaluateApp(String evaluateApp) {
		this.evaluateApp = evaluateApp;
	}
	
	@Size(min=0, max=255, message="应用名字长度不能超过 255 个字符")
	public String getAppName() {
		return appName;
	}

	public void setAppName(String appName) {
		this.appName = appName;
	}
	
	public String getEvaluateMsg() {
		return evaluateMsg;
	}

	public void setEvaluateMsg(String evaluateMsg) {
		this.evaluateMsg = evaluateMsg;
	}
	
	@Size(min=0, max=255, message="评价图片长度不能超过 255 个字符")
	public String getEvaluateImage() {
		return evaluateImage;
	}

	public void setEvaluateImage(String evaluateImage) {
		this.evaluateImage = evaluateImage;
	}
	
	@Size(min=0, max=255, message="应用描述长度不能超过 255 个字符")
	public String getAppDescribe() {
		return appDescribe;
	}

	public void setAppDescribe(String appDescribe) {
		this.appDescribe = appDescribe;
	}
	
	@Size(min=0, max=5, message="分数长度不能超过 5 个字符")
	public String getScore() {
		return score;
	}

	public void setScore(String score) {
		this.score = score;
	}
	
}