package com.jeesite.modules.admin.wenjuan.service;

import java.util.List;

import com.jeesite.common.service.CrudService;
import com.jeesite.modules.admin.wenjuan.dao.AdminQuestionItemDao;
import com.jeesite.modules.admin.wenjuan.dao.AdminQuestionnaireSurveyDao;
import com.jeesite.modules.admin.wenjuan.entity.AdminQuestionItem;
import com.jeesite.modules.admin.wenjuan.entity.AdminQuestionnaireSurvey;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.jeesite.common.entity.Page;


/**
 * 问卷调查表Service
 * @author wlc
 * @version 2022-06-18
 */
@Service
@Transactional(readOnly=true)
public class AdminQuestionnaireSurveyService extends CrudService<AdminQuestionnaireSurveyDao, AdminQuestionnaireSurvey> {
	
	@Autowired
	private AdminQuestionItemDao adminQuestionItemDao;
	
	/**
	 * 获取单条数据
	 * @param adminQuestionnaireSurvey
	 * @return
	 */
	@Override
	public AdminQuestionnaireSurvey get(AdminQuestionnaireSurvey adminQuestionnaireSurvey) {
		AdminQuestionnaireSurvey entity = super.get(adminQuestionnaireSurvey);
		if (entity != null){
			AdminQuestionItem adminQuestionItem = new AdminQuestionItem(entity);
			adminQuestionItem.setStatus(AdminQuestionItem.STATUS_NORMAL);
			entity.setAdminQuestionItemList(adminQuestionItemDao.findList(adminQuestionItem));
		}
		return entity;
	}
	
	/**
	 * 查询分页数据
	 * @param adminQuestionnaireSurvey 查询条件
	 * @param adminQuestionnaireSurvey.page 分页对象
	 * @return
	 */
	@Override
	public Page<AdminQuestionnaireSurvey> findPage(AdminQuestionnaireSurvey adminQuestionnaireSurvey) {
		return super.findPage(adminQuestionnaireSurvey);
	}
	
	/**
	 * 查询列表数据
	 * @param adminQuestionnaireSurvey
	 * @return
	 */
	@Override
	public List<AdminQuestionnaireSurvey> findList(AdminQuestionnaireSurvey adminQuestionnaireSurvey) {
		return super.findList(adminQuestionnaireSurvey);
	}
	
	/**
	 * 查询子表分页数据
	 * @param adminQuestionItem
	 * @param adminQuestionItem.page 分页对象
	 * @return
	 */
	public Page<AdminQuestionItem> findSubPage(AdminQuestionItem adminQuestionItem) {
		Page<AdminQuestionItem> page = adminQuestionItem.getPage();
		page.setList(adminQuestionItemDao.findList(adminQuestionItem));
		return page;
	}
	
	/**
	 * 保存数据（插入或更新）
	 * @param adminQuestionnaireSurvey
	 */
	@Override
	@Transactional(readOnly=false)
	public void save(AdminQuestionnaireSurvey adminQuestionnaireSurvey) {
		super.save(adminQuestionnaireSurvey);
		// 保存 AdminQuestionnaireSurvey子表
		for (AdminQuestionItem adminQuestionItem : adminQuestionnaireSurvey.getAdminQuestionItemList()){
			if (!AdminQuestionItem.STATUS_DELETE.equals(adminQuestionItem.getStatus())){
				adminQuestionItem.setQuestionnaireId(adminQuestionnaireSurvey);
				if (adminQuestionItem.getIsNewRecord()){
					adminQuestionItemDao.insert(adminQuestionItem);
				}else{
					adminQuestionItemDao.update(adminQuestionItem);
				}
			}else{
				adminQuestionItemDao.delete(adminQuestionItem);
			}
		}
	}
	
	/**
	 * 更新状态
	 * @param adminQuestionnaireSurvey
	 */
	@Override
	@Transactional(readOnly=false)
	public void updateStatus(AdminQuestionnaireSurvey adminQuestionnaireSurvey) {
		super.updateStatus(adminQuestionnaireSurvey);
	}
	
	/**
	 * 删除数据
	 * @param adminQuestionnaireSurvey
	 */
	@Override
	@Transactional(readOnly=false)
	public void delete(AdminQuestionnaireSurvey adminQuestionnaireSurvey) {
		super.delete(adminQuestionnaireSurvey);
		AdminQuestionItem adminQuestionItem = new AdminQuestionItem();
		adminQuestionItem.setQuestionnaireId(adminQuestionnaireSurvey);
		adminQuestionItemDao.deleteByEntity(adminQuestionItem);
	}
	
}