package com.jeesite.modules.admin.wenjuan.web;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.jeesite.modules.admin.wenjuan.entity.AdminQuestionnaireRecord;
import com.jeesite.modules.admin.wenjuan.service.AdminQuestionnaireRecordService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;

import com.jeesite.common.config.Global;
import com.jeesite.common.entity.Page;
import com.alibaba.fastjson.JSONValidator;
import com.jeesite.common.codec.EncodeUtils;
import com.jeesite.common.web.BaseController;

/**
 * 问卷调查记录表Controller
 * @author wlc
 * @version 2022-06-22
 */
@Controller
@RequestMapping(value = "${adminPath}/admin/adminQuestionnaireRecord")
public class AdminQuestionnaireRecordController extends BaseController {

	@Autowired
	private AdminQuestionnaireRecordService adminQuestionnaireRecordService;
	
	/**
	 * 获取数据
	 */
	@ModelAttribute
	public AdminQuestionnaireRecord get(String questionrecordId, boolean isNewRecord) {
		return adminQuestionnaireRecordService.get(questionrecordId, isNewRecord);
	}
	
	/**
	 * 查询列表
	 */
	@RequiresPermissions("admin:adminQuestionnaireRecord:view")
	@RequestMapping(value = {"list", ""})
	public String list(AdminQuestionnaireRecord adminQuestionnaireRecord, Model model) {
		model.addAttribute("adminQuestionnaireRecord", adminQuestionnaireRecord);
		return "modules/admin/wenjuan/adminQuestionnaireRecordList";
	}
	
	/**
	 * 查询列表数据
	 */
	@RequiresPermissions("admin:adminQuestionnaireRecord:view")
	@RequestMapping(value = "listData")
	@ResponseBody
	public Page<AdminQuestionnaireRecord> listData(AdminQuestionnaireRecord adminQuestionnaireRecord, HttpServletRequest request, HttpServletResponse response) {
		adminQuestionnaireRecord.setPage(new Page<>(request, response));
		Page<AdminQuestionnaireRecord> page = adminQuestionnaireRecordService.findPage(adminQuestionnaireRecord);
		return page;
	}

	/**
	 * 查看编辑表单
	 */
	@RequiresPermissions("admin:adminQuestionnaireRecord:view")
	@RequestMapping(value = "form")
	public String form(AdminQuestionnaireRecord adminQuestionnaireRecord, Model model) {
		model.addAttribute("adminQuestionnaireRecord", adminQuestionnaireRecord);
		return "modules/admin/wenjuan/adminQuestionnaireRecordForm";
	}

	/**
	 * 保存数据
	 */
	@RequiresPermissions("admin:adminQuestionnaireRecord:edit")
	@PostMapping(value = "save")
	@ResponseBody
	public String save(@Validated AdminQuestionnaireRecord adminQuestionnaireRecord) {
		adminQuestionnaireRecordService.save(adminQuestionnaireRecord);
		return renderResult(Global.TRUE, text("保存问卷调查记录表成功！"));
	}
	
	/**
	 * 删除数据
	 */
	@RequiresPermissions("admin:adminQuestionnaireRecord:edit")
	@RequestMapping(value = "delete")
	@ResponseBody
	public String delete(AdminQuestionnaireRecord adminQuestionnaireRecord) {
		adminQuestionnaireRecordService.delete(adminQuestionnaireRecord);
		return renderResult(Global.TRUE, text("删除问卷调查记录表成功！"));
	}
	
	/**
	 * 列表选择对话框
	 */
	@RequiresPermissions("admin:adminQuestionnaireRecord:view")
	@RequestMapping(value = "adminQuestionnaireRecordSelect")
	public String adminQuestionnaireRecordSelect(AdminQuestionnaireRecord adminQuestionnaireRecord, String selectData, Model model) {
		String selectDataJson = EncodeUtils.decodeUrl(selectData);
		if (selectDataJson != null && JSONValidator.from(selectDataJson).validate()){
			model.addAttribute("selectData", selectDataJson);
		}
		model.addAttribute("adminQuestionnaireRecord", adminQuestionnaireRecord);
		return "modules/admin/wenjuan/adminQuestionnaireRecordSelect";
	}
	
}